Algorithm Analysis
::::::::::::::::::

.. toctree::
    :caption: Algorithm Analysis
    :maxdepth: 2

    Objectives.rst
    WhatIsAlgorithmAnalysis.rst
    BigONotation.rst
    AnAnagramDetectionExample.rst
    PerformanceofPythonDataStructures.rst
    Lists.rst
    Dictionaries.rst
    Summary.rst
    KeyTerms.rst
    Exercises.rst
